API Documentation
=================

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst

   scarlet2

.. autosummary::
   :caption: Modules
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:

   scarlet2.constraint
   scarlet2.fft
   scarlet2.init
   scarlet2.interpolation
   scarlet2.io
   scarlet2.nn
   scarlet2.measure
   scarlet2.plot
   scarlet2.renderer
   scarlet2.wavelets

